# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-07-24 08:32
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_corporate', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='corporateimage',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AddField(
            model_name='corporateimage',
            name='business_name',
            field=models.CharField(blank=True, max_length=254, null=True, verbose_name='Business name'),
        ),
        migrations.AddField(
            model_name='corporateimage',
            name='name_file_logo',
            field=models.CharField(blank=True, max_length=254, null=True, verbose_name='Name file company logo'),
        ),
        migrations.AddField(
            model_name='corporateimage',
            name='name_file_seal',
            field=models.CharField(blank=True, max_length=254, null=True, verbose_name='Name file company seal'),
        ),
        migrations.AddField(
            model_name='corporateimage',
            name='name_file_sign',
            field=models.CharField(blank=True, max_length=254, null=True, verbose_name='Name file digital sign'),
        ),
        migrations.AddField(
            model_name='corporateimage',
            name='nid',
            field=models.CharField(blank=True, max_length=20, verbose_name='NID'),
        ),
    ]
